@@ -131,7 +131,7 @@ class ModelView(Model):
                 cursor.execute('SELECT arch, field_childs, id, type, ' \
                         'inherit, model ' \
                         'FROM ir_ui_view ' \
-                        'WHERE model = %s AND type = %s' \
+                        'WHERE model = %s AND type = %s ' \
                         'ORDER BY inherit DESC, priority ASC, id ASC',
                         (self._name, view_type))
             sql_res = cursor.fetchone()
@@ -219,7 +219,8 @@ class ModelView(Model):
         # Update arch and compute fields from arch
         parser = etree.XMLParser(remove_blank_text=True)
         tree = etree.fromstring(result['arch'], parser)
-        xarch, xfields = self._view_look_dom_arch(tree, result['type'])
+        xarch, xfields = self._view_look_dom_arch(tree, result['type'],
+                result['field_childs'])
         result['arch'] = xarch
         result['fields'] = xfields
 
@@ -255,10 +256,46 @@ class ModelView(Model):
         """
         return value
 
-    def _view_look_dom_arch(self, tree, type):
+    def _view_look_dom_arch(self, tree, type, field_children=None):
+        field_access_obj = self.pool.get('ir.model.field.access')
+
         fields_width = {}
         tree_root = tree.getroottree().getroot()
 
+        # Find field without read access
+        fread_accesses = field_access_obj.check(self._name,
+                self._columns.keys(), 'read', access=True)
+        fields_to_remove = list(x for x, y in fread_accesses.iteritems()
+                if not y)
+        for name, field in self._columns.iteritems():
+            for field_to_remove in fields_to_remove:
+                if field_to_remove in field.depends:
+                    fields_to_remove.append(name)
+
+        # Find field inherited without read access
+        for inherit_name in self._inherits:
+            inherit_obj = self.pool.get(inherit_name)
+            fread_accesses = field_access_obj.check(inherit_obj._name,
+                    inherit_obj._columns.keys(), 'read', access=True)
+            fields_to_remove += list(x for x, y in fread_accesses.iteritems()
+                    if not y and x not in self._columns.keys())
+            for name, field in inherit_obj._columns.iteritems():
+                for field_to_remove in fields_to_remove:
+                    if field_to_remove in field.depends:
+                        fields_to_remove.append(name)
+
+        # Remove field without read access
+        for field in fields_to_remove:
+            for element in tree.xpath(
+                    '//field[@name="%s"] | //label[@name="%s"]'
+                    % (field, field)):
+                if type == 'form':
+                    element.tag = 'label'
+                    element.attrib.clear()
+                elif type == 'tree':
+                    parent = element.getparent()
+                    parent.remove(element)
+
         if type == 'tree':
             viewtreewidth_obj = self.pool.get('ir.ui.view_tree_width')
             viewtreewidth_ids = viewtreewidth_obj.search([
@@ -272,6 +309,17 @@ class ModelView(Model):
         fields_def = self.__view_look_dom(tree_root, type,
                 fields_width=fields_width)
 
+        if field_children:
+            fields_def.setdefault(field_children, {'name': field_children})
+            model, field = None, None
+            if field_children in self._columns:
+                model = self
+                field = self._columns[field_children]
+            elif field_children in self._inherit_fields:
+                model_name, model, field = self._inherit_fields[field_children]
+            if model and field and field.model_name == model._name:
+                fields_def.setdefault(field.field, {'name': field.field})
+
         for field_name in fields_def.keys():
             if field_name in self._columns:
                 field = self._columns[field_name]
