@@ -33,6 +33,7 @@ def dispatch(host, port, protocol, database_name, user, session, object_type,
             try:
                 database = Database(database_name).connect()
                 cursor = database.cursor()
+                cursor.close()
             except Exception:
                 return False
             res = security.login(database_name, user, session)
@@ -80,8 +81,10 @@ def dispatch(host, port, protocol, database_name, user, session, object_type,
             database = Database().connect()
             try:
                 cursor = database.cursor()
-                res = database.list(cursor)
-                cursor.close(close=True)
+                try:
+                    res = database.list(cursor)
+                finally:
+                    cursor.close(close=True)
             except Exception:
                 res = []
             return res
